:focus {
  outline: none !important;
}
html {
  scroll-behavior: smooth;
}
body {
  background-color: #f5f5f5;
}
html, body {
  height: 100%;
}
.mdc-top-app-bar__title {
  font-weight: 400;
  letter-spacing: .02em;
}
.centered-page-item {
  display: block;
  margin-left: auto;
  margin-right: auto;
}
.layout-tab-item {
  display: none;
}
@media (min-width: 840px) {
  .layout-grid-desktop .mdc-layout-grid__inner {
    justify-content: center;
    margin-left: auto;
    margin-right: auto;
    max-width: 920px !important;
  }
  .mdc-card:hover {
    box-shadow: 0px 5px 5px -3px rgba(0, 0, 0, 0.2),0px 8px 10px 1px rgba(0, 0, 0, 0.14),0px 3px 14px 2px rgba(0,0,0,.12) !important;
  }
  .mdc-image-list__image:hover {
    box-shadow: 0px 5px 5px -3px rgba(0, 0, 0, 0.2),0px 8px 10px 1px rgba(0, 0, 0, 0.14),0px 3px 14px 2px rgba(0,0,0,.12) !important;
  }
}
.card-body-text {
  padding: 0 1rem 8px;
  color: rgba(0,0,0,.54);
}
.card-title-text {
  padding: 1rem;
}
.card-title-headline {
  margin: 0;
}
.rounded-corner-card {
  height: 100% !important;
}
.fixed-size-background-img {
  height: 250px;
}
.otw-card-background {
  background: url("../Image_Assets/Resources_Tab/otw_card_image2.jpg") #000000 center/cover no-repeat;
  background-size: 100% auto;
}
.replit-card-background {
  background: url("../Image_Assets/Resources_Tab/replit_card_image.png") #0d2332 center/cover no-repeat;
  background-size: 100% auto;
}
.smashthestack-card-background {
  background: url("../Image_Assets/Resources_Tab/STS_card_image.png") #000000 center/cover no-repeat;
  background-size: 140% auto;
}
.cybrary-card-background {
  background: url("../Image_Assets/Resources_Tab/Cybrary_card_image.png") #0d2332 center/cover no-repeat;
}
.udacity-card-background {
  background: url("../Image_Assets/Resources_Tab/udacity_card_image.png") #0d2332 center/cover no-repeat;
}
.codewars-card-background {
  background: url("../Image_Assets/Resources_Tab/codewars_resource_card_image.png") #282828 center/cover no-repeat;
  background-size: 100% auto;
}
.codecademy-card-background {
  background: url("../Image_Assets/Resources_Tab/codecademy_card_image.png") #0d2332 center/cover no-repeat;
}
.reeeeeee-card-background {
  background: url("../Image_Assets/Resources_Tab/reeeeee_card_image.png") #b1361e center/cover no-repeat;
  background-size: 104%;
}
.cyberchallenge-card-background {
  background: url("../Image_Assets/Resources_Tab/cyberchallenge_card_image.jpg") #0d2332 center/cover no-repeat;
}
.picoctf-card-background {
  background: url("../Image_Assets/Resources_Tab/picoctf_card_image.png") #0d2332 center/cover no-repeat;
}
.endorsement-card-background {
  background: url("../Image_Assets/Resources_Tab/endorsement_card_image.png") #0d2332 center/cover no-repeat;
}
.hak5-card-background {
  background: url("../Image_Assets/Resources_Tab/hak5_card_image.png") #9e9e9e center/cover no-repeat;
  background-size: 100%;
}
.futurelearn-card-background {
  background: url("../Image_Assets/Resources_Tab/futurelearn_card_image.png") #0d2332 center/cover no-repeat;
}
.homepage_welcome_card {
  background: url('../Image_Assets/Home_Tab/home_card_image.png') #0d2332 center / cover no-repeat;
  height: 100%;
  max-height: 400px;
  background-size: auto 100%;
}
.cdsurvivalguide_home_card {
  background: url('../Image_Assets/Home_Tab/alice_asset_survival_guide.png') #4a3c5f center / cover no-repeat !important;
}
.hmg_programme_home_card {
  background: url('../Image_Assets/Home_Tab/CD_Home_Resources.png') #0d2332 center / cover no-repeat;
  max-height: 250px;
}
.home_discord_invite_card {
  background: url("../Image_Assets/Home_Tab/discord_logo_home_card_image.svg") #2C2F33 center/cover no-repeat;
  background-size: 100% auto;
}
.home_assess_card_reminder {
  background: url("../Image_Assets/elite_alt_card.png") #0d2332 center/cover no-repeat;
}
.medium_blog_main_card_image {
  background: url("../Image_Assets/Home_Tab/medium_blog_card_image.png") #9f5335 center/cover no-repeat;
}
.custom_padded_font_card_home {
  padding: 0 1rem 8px;
  height: 100% !important;
  font-size: 18px !important;
  color: rgba(0,0,0,.54);
}
.hmg_programme_body_text {
  padding: 1rem 1rem 8px;
  height: auto;
  font-size: 18px !important;
  color: rgba(0,0,0,.54);
  overflow: auto;
}
.home_tab_welcome_banner_image {
  background: url('../Image_Assets/Home_Tab/home_card_image.png') #0d2332 center / cover no-repeat;
  margin-top: auto;
  margin-bottom: auto;
  height: 100%
}
.override_textfield_bottom_padding {
  padding-bottom: 20px !important;
}
.homepage_introduction_card {
  height: auto;
  color: rgba(255, 255, 255, 0.85) !important;
  font-size: 18px !important;
  padding: 0 1rem 8px;
}
.cdsurvivalguide_body_text {
  padding: 0 1rem 8px;
  height: 100% !important;
  font-size: 18px !important;
  color: rgba(0,0,0,.54);
}
.page-intro-text-card {
  height: auto;
  background-color: #0d2332;
  color: rgba(255, 255, 255, 0.85) !important;
  overflow: auto;
}
.mdc-card__primary-action {
  height: inherit;
  border-radius: 15px;
}
.mdc-typography--body1 {
  height: inherit !important;
}
.mdc-image-list__image {
  border-radius: 24px;
}
.generic-card-text {
  padding: 0 1rem 8px;
  color: rgba(0,0,0,.54);
}
.mdc-menu.mdc-menu-surface.mdc-menu-surface--open {
	max-height: none !important;
	max-width: none !important;
}
.mdc-menu.mdc-menu-surface {
  overflow: hidden;
}
.project_card_fixed_background {
  height: 250px !important;
}
.cdbotmain_card_image {
  background: url('../Image_Assets/Discord_Tab/discord_card_main.png') #e8e4e7 center/cover no-repeat;
}
.cdmathsbot_card_image {
  background: url('../Image_Assets/Discord_Tab/mathsbot_card_image.svg') #7289da center/cover no-repeat;
  background-size: 90%
}
.project_card_menu_icons {
  vertical-align: bottom;
  padding-right: 5px;
}
.discord_swatch_hover_liftoff {
  position: relative;
  top: 0;
}
.discord_swatch_hover_liftoff:hover {
  box-shadow: 0 4px 14px 0 rgba(0,0,0,.4);
  transition: all .12s ease-out;
  top: -4px;
}
.hibp_project_card_image {
  background: url('../Image_Assets/HIBP_Logo_Background.png') #c76a6a center / cover no-repeat;
}
.hibp_search_card_image {
  background: url('../Image_Assets/HIBP_Logo_Background.png') #c76a6a center / cover no-repeat;
}
.xkcd_card_fetch_image {
  background: url('../Image_Assets/Discord_Tab/Bot_XKCD_Fetcher.png') #36393f center / cover no-repeat;
  background-size: 100%;
}
.mdc-text-field--focused:not(.mdc-text-field--disabled) .mdc-floating-label {
  color: #0d2332;
}
.textfield_card_primary_btn {
  color: #0d2332 !important;
  margin-left: 5px;
}
.textfield_leading_notch_radius {
  border-radius: 28px 0 0 28px !important;
}
.textfield_span_width_full {
  width: 100%;
}
.mdc-text-field::before, .mdc-text-field::after {
  width: auto !important;
}
.discord_bot_quote_card_image {
  background: url('../Image_Assets/Discord_Tab/Discord_Quote_Image_Card.png') #36393f center/cover no-repeat;
  background-size: 100%;
}
.discord_api_docs_card_image {
  background: url('../Image_Assets/Discord_Tab/discord_api_docs_card_image.png') #36393e center/cover no-repeat;
  background-size: 100% auto;
}
.rounded_corner_list_item {
  border-radius: 15px !important;
}
.generic_class_center_item {
  margin-left: auto;
  margin-right: auto;
}
.generic_contrib_card_list {
  overflow: hidden;
}
.generic_contrib_card_list:hover {
  overflow: auto;
}
.contrib_list_item_contributor {
  color: rgba(0, 0, 0, 0.54);
}
.contrib_list_pfp_logo {
  vertical-align: bottom;
  border-radius: 30%;
}
.contrib_list_pfp_logo:hover {
  cursor: pointer;
}
.contrib_list_secondary_logo {
  color: #0d2332;
}
.contrib_list_secondary_logo:hover {
  cursor: pointer;
}
.form_padding_adjustments {
  padding-bottom: 5px;
  padding-left: 3px;
}
.cdapp_main_card_image {
  background: url('../Image_Assets/App_Tab/app_card_main_img.png') #ef1580 center/cover no-repeat;
  background-size: auto 110%;
}
.App_Contrib_Flutter_Docs {
  background: url("../Image_Assets/App_Tab/Contribute_Programming.gif") #283247 center/cover no-repeat;
}
.cdsurvivalguide_site_card_image {
  background: url("../Image_Assets/Websites_Tab/cdsurvivial_guide_card_image.png") #106668 center/cover no-repeat;
}
.challenge_master_site_card_image {
  background: url("../Image_Assets/Js_Logo_Background.png") #ffab00 center/cover no-repeat;
  background-size: 100% auto;
}
.app_website_site_card_image {
    background: url("../Image_Assets/Firebase_Logo_Background.png") #039be5 center/cover no-repeat;
    background-size: 130% auto;
}
.discord_bot_assess_card_image {
  background: url("../Image_Assets/Discord_Tab/bot_get_game_level_no_hint_owo.jpg") #363940 center/cover no-repeat;
  background-size: 100% auto;
}
.discord_dwouca_owo_gang_lmao {
  background: url("../Image_Assets/Discord_Tab/owo_gang_dwouca.jpg") #363940 center/cover no-repeat;
  background-size: 100% auto;
}
.website_tab_help_us_card_image {
  background: url("../Image_Assets/Websites_Tab/responsive_design_card_image.gif") #9d9f9e center/cover no-repeat;
  background-size: 100% auto;
}
.cd_site_guide_card_image {
  background: url("../Image_Assets/Websites_Tab/cd_survivalguide_card_image.jpg") #0f1722 center/cover no-repeat;
  background-size: 90% auto;
}
.app_site_alt_card_image {
  background: url("../Image_Assets/Websites_Tab/app_website_card_image.jpg") #091b27 center/cover no-repeat;
  background-size: 85% auto;
}
.alexa_skill_card_image {
  background: url("../Image_Assets/Websites_Tab/cd_alexa_skill_card_image.png") #ffffff center/cover no-repeat;
  background-size: 100% auto;
}
.resources-tab-card {
  height: 100% !important;
  min-width: 200px;
}
.mdc-card {
  border-radius: 15px;
}
.padded-resource-card {
  padding: 1rem;
}
.resource-card-title {
  margin: 0;
}
.resource-card-subtitle {
  color: var(--mdc-theme-text-secondary-on-background,rgba(0,0,0,.54));
  margin: 0;
  overflow: hidden;
}
.resource-card-secondary {
  padding: 0 1rem 8px;
  color: var(--mdc-theme-text-secondary-on-background,rgba(0,0,0,.54));
  height: inherit;
}
@media (min-width: 480px) {
  .home_tab_welcome_banner_image {
    height: 380px !important;
  }
}
@media (max-width: 839px) {
  .desktop-only-card {
    display: none;
  }
  .mdc-card__actions {
    height: auto;
  }
  .spaced-card-mobile {
    max-width: 80%;
    margin-left: auto;
    margin-right: auto;
  }
  #scrollPageTop {
    z-index: 7 !important;
  }
  .mdc-dialog .mdc-dialog__surface {
    max-height: calc(100vh - 72px) !important;
  }
}
#scrollPageTop {
  position: fixed;
  display: block;
  right: 1rem;
  bottom: 1rem;
  z-index: 900;
}
@media (min-width: 1024px) {
   #scrollPageTop {
     bottom: 1.5rem;
     right: 1.5rem;
  }
  .resized-dialog-window {
    max-width: 1004px !important;
  }
}
@media (max-width: 899px) {
   #scrollPageTop {
     max-width: 40px;
     max-height: 40px;
  }
}
@media (min-width: 480px) and (max-width: 599px) {
   #scrollPageTop {
     display: none;
  }
}
.theme-switch {
  margin-left: auto;
  margin-right: 5px;
}
.shifted-form-field {
  margin-left: auto;
}
.elevated-soundboard-surface {
	display: -ms-inline-flexbox;
	display: inline-flex;
	-ms-flex-pack: distribute;
	justify-content: space-around;
	min-height: 100px;
  height: inherit;
  width: 100%;
	-ms-flex-align: center;
	align-items: center;
  color: var(--mdc-theme-text-secondary-on-background, rgba(0,0,0,.54));
}
.spaced-out-subheader {
  margin-bottom: 0px;
  margin-top: 0px;
  padding-bottom: 0px;
  padding-top: 0px;
}
.unselectable-text {
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -khtml-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}
.projects-tab-card {
  height: 100% !important;
  min-width: 200px;
}
.padded-projects-card {
  padding: 1rem;
}
.projects-card-title {
  margin: 0;
}
.projects-card-subtitle {
  color: var(--mdc-theme-text-secondary-on-background, rgba(0,0,0,.54));
  margin: 0;
  overflow: hidden;
}
.projects-card-secondary {
  padding: 0 1rem 8px;
  color: var(--mdc-theme-text-secondary-on-background, rgba(0,0,0,.54));
  height: inherit;
}
.placeholder-image {
  background: url('https://cdn.glitch.com/3f2aa87c-0707-4d16-b533-62cb0b69db35%2FDiscord%20Bot%20List%20Icon%20-%20Large%202.png?1543200818856') #37373d center/cover no-repeat;
  background-size: auto 100%;
}
.events-body-padded {
  padding-bottom: 12px;
}
.events-elite-card {
  background: url('../Image_Assets/cd_elite_bg.png') #0d2332 center/cover no-repeat;
  background-size: auto 112%;
}
.events-cft-card {
  background: url('../Image_Assets/Home_Tab/Cyber_FastTrack.png') #0d2332 center/cover no-repeat;
  background-size: auto 110%;
}
.events-ggcs-card {
  background: url('../Image_Assets/Home_Tab/ggcs.png') #0d2332 center/cover no-repeat;
  background-size: auto 110%;
}
.events-prereg-card {
  background: url('../Image_Assets/daniel-josef-540635-unsplash.jpg') #780036 center/cover no-repeat;
}
.events-assess-card {
  background: url('../Image_Assets/assess_events_card.png') #0d2332 center/cover no-repeat;
  background-size: auto 100%;
}
.events-game-card {
  background: url('../Image_Assets/cs_game_event.png') #0d2332 center/cover no-repeat;
  background-size: auto 100%;
}
.events-essentials-card {
  background: url('../Image_Assets/essentials_event_card.jpg') #0d2332 center/cover no-repeat;
  background-size: auto 100%;
}
.cd_richpresence_card {
  background: url('../Image_Assets/discord_rich_presence.png') #778ff1 center/cover no-repeat;
  background-size: auto 100%;
}
.alexa_skill_card_project {
  background: url('../Image_Assets/alexa_skill_card.png') #232F3E center/cover no-repeat;
  background-size: auto 130%;
}
.main-page-card-home {
  background: url('../Image_Assets/cd_main_card.png') #0d2332 center/cover no-repeat;
}
.leading-notch-textfield {
  border-radius: 8px 0 0 8px !important;
}
.trailling-notch-textfield {
  border-radius: 0 8px 8px 0 !important;
}
.adjusted-card-actions {
  min-height: initial !important;
}
.padded-dialog-content {
  padding-top: 24px !important;
}
.mdc-dialog__content code {
  border-radius: 3px;
  font-size: 85%;
  margin: 0;
  padding: .2em .4em;
}
.mdc-dialog__content h1, .mdc-dialog__content h2 {
  border-bottom: 1px solid #eaecef;
  padding-bottom: .3em;
}
.mdc-dialog__content h1 {
  font-size: 2em;
}
.mdc-dialog__content h1, .mdc-dialog__content h2, .mdc-dialog__content h3, .mdc-dialog__content h4, .mdc-dialog__content h5, .mdc-dialog__content h6 {
	font-weight: 600;
	line-height: 1.25;
	margin-bottom: 16px;
	margin-top: 24px;
}
.mdc-dialog__content {
	word-wrap: break-word;
}
.mdc-dialog__content {
	font-family: Roboto,sans-serif;
	font-size: 16px;
	line-height: 1.5;
	word-wrap: break-word;
}
.mdc-dialog__content blockquote, .mdc-dialog__content details, .mdc-dialog__content dl, .mdc-dialog__content ol, .mdc-dialog__content p, .mdc-dialog__content pre, .mdc-dialog__content table, .mdc-dialog__content ul {
	margin-bottom: 16px;
	margin-top: 0;
}
.mdc-dialog__content ol, .mdc-dialog__content ul {
	padding-left: 2em;
}
.mdc-dialog__content h4 {
	font-size: 1em;
}
.mdc-dialog__content pre {
	border-radius: 3px;
	font-size: 85%;
	line-height: 1.45;
	overflow: auto;
	padding: 16px;
}
.mdc-dialog__content pre code, .mdc-dialog__content pre tt {
	background-color: transparent;
	border: 0;
	display: inline;
	line-height: inherit;
	margin: 0;
	max-width: auto;
	overflow: visible;
	padding: 0;
	word-wrap: normal;
}
.mdc-dialog__content pre > code {
	background: transparent;
	border: 0;
	font-size: 100%;
	margin: 0;
	padding: 0;
	white-space: pre;
	word-break: normal;
}
.mdc-dialog__content img {
	box-sizing: content-box;
	max-width: 100%;
}
.nav-img-main {
	max-width: 100% !important;
}
.mdc-drawer__header {
	padding-left: 0px !important;
	padding-right: 0px !important;
}
.padded-top-card {
  padding-top: 1rem;
}
.welcome-text-card {
  max-height: 306px;
  overflow: auto;
}
.events-section-text {
	padding: 0;
	margin: 5px;
}
.red-events-text {
  color: #c04b4e !important;
}
:root {
  --mdc-theme-primary: #0d2332;
}
.mdc-snackbar__action::before, .mdc-snackbar__action::after {
	background-color: rgba(255, 255, 255, 0.87);
}
.mdc-snackbar__action:not(:disabled) {
	color: rgba(255, 255, 255, 0.87) !important;
}
.mdc-drawer .mdc-list-item--activated .mdc-list-item__graphic {
	color: var(--mdc-theme-primary, #0d2332);
}
.mdc-drawer .mdc-list-item--activated {
	color: var(--mdc-theme-primary, #0d2332);
}
.mdc-tab--active .mdc-tab__icon {
	color: var(--mdc-theme-primary, #0d2332);
}
.mdc-tab--active .mdc-tab__text-label {
	color: var(--mdc-theme-primary, #0d2332);
}
.mdc-fab {
	background-color: var(--mdc-theme-primary, #0d2332);
}
.mdc-dialog__content pre {
  background-color: #f6f8fa;
}
:not(pre) > code {
  background-color: rgba(27,31,35,.05);
}
.light-dark-text {
  color: rgba(255,255,255,.85) !important;
}
.colored-card-bg {
  background-color: #0d2332;
}
